@@ -1,22 +1,20 @@
 package Dist::Zilla::Plugin::Mercurial::Check;
-{
-  $Dist::Zilla::Plugin::Mercurial::Check::VERSION = '0.07';
-}
-
+$Dist::Zilla::Plugin::Mercurial::Check::VERSION = '0.08';
 use strict;
 use warnings;
 
 use Moose;
+use IPC::System::Simple (qw( capture ));
 
 with 'Dist::Zilla::Role::BeforeRelease';
 
 sub before_release {
     my $self = shift;
 
-    my $branch = `hg branch`;
+    my $branch = capture('hg', 'branch');
     chomp $branch;
 
-    if ( my @output = `hg status` ) {
+    if ( my @output = capture('hg', 'status') ) {
         my $errmsg
             = "This branch ($branch) has some files that are not yet committed:\n"
             . join q{}, map {"\t$_"} @output;
@@ -46,7 +44,7 @@ Dist::Zilla::Plugin::Mercurial::Check - Check for modified/removed/unknown files
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
